'''pycse is a set of python modules and functions for python calculations in
Science and Engineering.

'''

__version__ = '1.6'
'''
9/16/2013 made odelay multivariable and return arrays
10/19/2013 changed bvp to work for multiple first order equations.
9/4/2014 minor changes to odelay documentation and bug fix on endpoint
9/29/2014 added sandbox.py
'''
from .PYCSE import *

# quantities math functions
from .qmath import *
